Package: checkmate
Type: Package
Title: Fast and Versatile Argument Checks
Description: Tests and assertions to perform frequent argument checks. A
    substantial part of the package was written in C to minimize any worries
    about execution time overhead.
Version: 1.8.5
Authors@R: c(
    person("Michel", "Lang", NULL, "michellang@gmail.com", role = c("cre", "aut")),
    person("Bernd", "Bischl", NULL, "bernd_bischl@gmx.de", role = "ctb")
    )
URL: https://github.com/mllg/checkmate
URLNote: https://github.com/mllg/checkmate
BugReports: https://github.com/mllg/checkmate/issues
NeedsCompilation: yes
ByteCompile: yes
Encoding: UTF-8
Depends: R (>= 3.0.0)
Imports: backports (>= 1.1.0), utils
Suggests: R6, bit, fastmatch, data.table (>= 1.9.8), devtools, ggplot2,
        knitr, magrittr, microbenchmark, rmarkdown, testthat (>=
        0.11.0), tibble
License: BSD_3_clause + file LICENSE
VignetteBuilder: knitr
RoxygenNote: 6.0.1
Collate: 'AssertCollection.R' 'allMissing.R' 'anyInfinite.R'
        'anyMissing.R' 'anyNaN.R' 'asInteger.R' 'assert.R' 'helper.R'
        'makeExpectation.R' 'makeTest.R' 'makeAssertion.R'
        'checkAccess.R' 'checkArray.R' 'checkAtomic.R'
        'checkAtomicVector.R' 'checkBit.R' 'checkCharacter.R'
        'checkChoice.R' 'checkClass.R' 'checkComplex.R' 'checkCount.R'
        'checkDataFrame.R' 'checkDataTable.R' 'checkDate.R'
        'checkDirectoryExists.R' 'checkEnvironment.R' 'checkFALSE.R'
        'checkFactor.R' 'checkFileExists.R' 'checkFlag.R'
        'checkFunction.R' 'checkInt.R' 'checkInteger.R'
        'checkIntegerish.R' 'checkList.R' 'checkLogical.R'
        'checkMatrix.R' 'checkNamed.R' 'checkNames.R' 'checkNull.R'
        'checkNumber.R' 'checkNumeric.R' 'checkOS.R' 'checkPOSIXct.R'
        'checkPathForOutput.R' 'checkR6.R' 'checkScalar.R'
        'checkScalarNA.R' 'checkSetEqual.R' 'checkString.R'
        'checkSubset.R' 'checkTRUE.R' 'checkTibble.R' 'checkVector.R'
        'coalesce.R' 'isIntegerish.R' 'matchArg.R' 'qassert.R'
        'qassertr.R' 'vname.R' 'wfwl.R' 'zzz.R'
Packaged: 2017-10-24 12:50:38 UTC; lang
Author: Michel Lang [cre, aut],
  Bernd Bischl [ctb]
Maintainer: Michel Lang <michellang@gmail.com>
Repository: CRAN
Date/Publication: 2017-10-24 13:28:31 UTC
Built: R 3.3.2; x86_64-w64-mingw32; 2018-05-26 16:14:38 UTC; windows
Archs: x64
